@@ -133,7 +133,7 @@ gPodderSettings = {
     'on_quit_ask': (bool, True,
       ("Ask the user to confirm quitting the application.")),
     'auto_download': (str, 'never',
-      ("Auto download episodes (never, minimized, always)")),
+      ("Auto download episodes (never, minimized, always) - Fremantle also supports 'quiet'")),
     'do_not_show_new_episodes_dialog': (bool, False,
       ("Do not show the new episodes dialog after updating feed cache when "
         "gPodder is not minimized")),
@@ -201,8 +201,6 @@ gPodderSettings = {
     'on_drag_mark_played': (bool, False,
       ("Mark episode as played when using drag'n'drop to copy/open it")),
 
-    'feed_update_skipping': (bool, False,
-      ('Skip podcasts that are unlikely to have new episodes when updating feeds.')),
     'allow_empty_feeds': (bool, True,
       ('Allow subscribing to feeds without episodes')),
 
@@ -351,6 +349,25 @@ class Config(dict):
         if self.__save_thread is not None:
             self.save()
 
+    def get_backup(self):
+        """Create a backup of the current settings
+
+        Returns a dictionary with the current settings which can
+        be used with "restore_backup" (see below) to restore the
+        state of the configuration object at a future point in time.
+        """
+        return dict(self)
+
+    def restore_backup(self, backup):
+        """Restore a previously-created backup
+
+        Restore a previously-created configuration backup (created
+        with "get_backup" above) and notify any observer about the
+        changed settings.
+        """
+        for key, value in backup.iteritems():
+            setattr(self, key, value)
+
     def save(self, filename=None):
         if filename is None:
             filename = self.__filename
