@@ -24,13 +24,11 @@
 #
 
 import gpodder
-from gpodder.liblogger import log
 
 from gpodder import util
 from gpodder import download
 
 import gtk
-import gobject
 
 import collections
 
