@@ -30,6 +30,7 @@ _ = gpodder.gettext
 import atexit
 import datetime
 import os
+import sys
 import threading
 import time
 
@@ -42,6 +43,19 @@ from gpodder import minidb
 import mygpoclient
 mygpoclient.user_agent += ' ' + gpodder.user_agent
 
+MYGPOCLIENT_REQUIRED = '1.4'
+
+if not hasattr(mygpoclient, 'require_version') or \
+        not mygpoclient.require_version(MYGPOCLIENT_REQUIRED):
+    print >>sys.stderr, """
+    Please upgrade your mygpoclient library.
+    See http://thpinfo.com/2010/mygpoclient/
+
+    Required version:  %s
+    Installed version: %s
+    """ % (MYGPOCLIENT_REQUIRED, mygpoclient.__version__)
+    sys.exit(1)
+
 from mygpoclient import api
 
 from mygpoclient import util as mygpoutil
@@ -108,16 +122,19 @@ class UpdateDeviceAction(object):
 
 class EpisodeAction(object):
     __slots__ = {'podcast_url': str, 'episode_url': str, 'device_id': str,
-                 'action': str, 'timestamp': int, 'position': str}
+                 'action': str, 'timestamp': int,
+                 'started': int, 'position': int, 'total': int}
 
     def __init__(self, podcast_url, episode_url, device_id, \
-            action, timestamp, position):
+            action, timestamp, started, position, total):
         self.podcast_url = podcast_url
         self.episode_url = episode_url
         self.device_id = device_id
         self.action = action
         self.timestamp = timestamp
+        self.started = started
         self.position = position
+        self.total = total
 
 # New entity name for "received" actions
 class ReceivedEpisodeAction(EpisodeAction): pass
@@ -166,6 +183,21 @@ class MygPoClient(object):
         self._worker_thread = None
         atexit.register(self._at_exit)
 
+    def create_device(self):
+        """Uploads the device changes to the server
+
+        This should be called when device settings change
+        or when the mygpo client functionality is enabled.
+        """
+        # Remove all previous device update actions
+        self._store.remove(self._store.load(UpdateDeviceAction))
+
+        # Insert our new update action
+        action = UpdateDeviceAction(self.device_id, \
+                self._config.mygpo_device_caption, \
+                self._config.mygpo_device_type)
+        self._store.save(action)
+
     def get_rewritten_urls(self):
         """Returns a list of rewritten URLs for uploads
 
@@ -234,10 +266,15 @@ class MygPoClient(object):
         else:
             raise Exception('Webservice access not enabled')
 
+    def _convert_played_episode(self, episode, start, end, total):
+        return EpisodeAction(episode.channel.url, \
+                episode.url, self.device_id, 'play', \
+                int(time.time()), start, end, total)
+
     def _convert_episode(self, episode, action):
         return EpisodeAction(episode.channel.url, \
                 episode.url, self.device_id, action, \
-                int(time.time()), None)
+                int(time.time()), None, None, None)
 
     def on_delete(self, episodes):
         log('Storing %d episode delete actions', len(episodes), sender=self)
@@ -247,6 +284,10 @@ class MygPoClient(object):
         log('Storing %d episode download actions', len(episodes), sender=self)
         self._store.save(self._convert_episode(e, 'download') for e in episodes)
 
+    def on_playback_full(self, episode, start, end, total):
+        log('Storing full episode playback action', sender=self)
+        self._store.save(self._convert_played_episode(episode, start, end, total))
+
     def on_playback(self, episodes):
         log('Storing %d episode playback actions', len(episodes), sender=self)
         self._store.save(self._convert_episode(e, 'play') for e in episodes)
@@ -269,10 +310,6 @@ class MygPoClient(object):
 
         self.flush()
 
-    @property
-    def actions(self):
-        return self._cache.get('actions', Actions.NONE)
-
     def _at_exit(self):
         self._worker_proc(forced=True)
         self._store.commit()
@@ -353,14 +390,8 @@ class MygPoClient(object):
                     self._config.mygpo_password, self._config.mygpo_server)
             log('Reloading settings.', sender=self)
         elif name.startswith('mygpo_device_'):
-            # Remove all previous device update actions
-            self._store.remove(self._store.load(UpdateDeviceAction))
-
-            # Insert our new update action
-            action = UpdateDeviceAction(self.device_id, \
-                    self._config.mygpo_device_caption, \
-                    self._config.mygpo_device_type)
-            self._store.save(action)
+            # Update or create the device
+            self.create_device()
 
     def synchronize_episodes(self, actions):
         log('Starting episode status sync.', sender=self)
@@ -371,14 +402,15 @@ class MygPoClient(object):
             return api.EpisodeAction(action.podcast_url, \
                     action.episode_url, action.action, \
                     action.device_id, since, \
-                    action.position)
+                    action.started, action.position, action.total)
 
         def convert_from_api(action):
             dt = mygpoutil.iso8601_to_datetime(action.timestamp)
             since = int(dt.strftime('%s'))
             return ReceivedEpisodeAction(action.podcast, \
                     action.episode, action.device, \
-                    action.action, since, action.position)
+                    action.action, since, \
+                    action.started, action.position, action.total)
 
         try:
             save_since = True
