@@ -44,7 +44,6 @@ import re
 import subprocess
 from htmlentitydefs import entitydefs
 import time
-import locale
 import gzip
 import datetime
 import threading
@@ -476,24 +475,18 @@ def format_filesize(bytesize, use_si_units=False, digits=2):
     return ('%.'+str(digits)+'f %s') % (used_value, used_unit)
 
 
-def delete_file( path):
-    """
-    Tries to delete the given filename and silently 
-    ignores deletion errors (if the file doesn't exist).
-    Also deletes extracted cover files if they exist.
-    """
-    log( 'Trying to delete: %s', path)
-    try:
-        os.unlink( path)
-        # Remove any extracted cover art that might exist
-        for cover_file in glob.glob( '%s.cover.*' % ( path, )):
-            os.unlink( cover_file)
+def delete_file(filename):
+    """Delete a file from the filesystem
 
+    Errors (permissions errors or file not found)
+    are silently ignored.
+    """
+    try:
+        os.remove(filename)
     except:
         pass
 
 
-
 def remove_html_tags(html):
     """
     Remove HTML tags from a string and replace numeric and
@@ -864,33 +857,34 @@ def url_add_authentication(url, username, password):
     return urlparse.urlunsplit(url_parts)
 
 
+def urlopen(url):
+    """
+    An URL opener with the User-agent set to gPodder (with version)
+    """
+    username, password = username_password_from_url(url)
+    if username is not None or password is not None:
+        url = url_strip_authentication(url)
+        password_mgr = urllib2.HTTPPasswordMgrWithDefaultRealm()
+        password_mgr.add_password(None, url, username, password)
+        handler = urllib2.HTTPBasicAuthHandler(password_mgr)
+        opener = urllib2.build_opener(handler)
+    else:
+        opener = urllib2.build_opener()
+
+    headers = {'User-agent': gpodder.user_agent}
+    request = urllib2.Request(url, headers=headers)
+    return opener.open(request)
+
 def get_real_url(url):
     """
     Gets the real URL of a file and resolves all redirects.
     """
     try:
-        username, password = username_password_from_url(url)
-        if username or password:
-            url = url_strip_authentication(url)
-            log('url=%s, username=%s, password=%s', url, username, password)
-            password_mgr = urllib2.HTTPPasswordMgrWithDefaultRealm()
-            password_mgr.add_password(None, url, username, password)
-            handler = urllib2.HTTPBasicAuthHandler(password_mgr)
-            opener = urllib2.build_opener(handler)
-            return opener.open(url).geturl()
-        else:
-            return urlopen(url).geturl()
+        return urlopen(url).geturl()
     except:
         log('Error getting real url for %s', url, traceback=True)
         return url
 
-def urlopen(url):
-    """
-    An URL opener with the User-agent set to gPodder (with version)
-    """
-    headers = {'User-agent': gpodder.user_agent}
-    request = urllib2.Request(url, headers=headers)
-    return urllib2.urlopen(request)
 
 def find_command( command):
     """
@@ -1428,3 +1422,20 @@ def get_hostname():
     # Fallback - but can this give us "localhost"?
     return socket.gethostname()
 
+def detect_device_type():
+    """Device type detection for gpodder.net
+
+    This function tries to detect on which
+    kind of device gPodder is running on.
+
+    Possible return values:
+    desktop, laptop, mobile, server, other
+    """
+    if gpodder.ui.maemo:
+        return 'mobile'
+    elif glob.glob('/proc/acpi/battery/*'):
+        # Linux: If we have a battery, assume Laptop
+        return 'laptop'
+
+    return 'desktop'
+
